pub struct ListProjectsQuery {
pub limit: Option<u32>,
pub after: Option<String>,
pub include_archived: Option<bool>,
}Available on crate feature
administration-types only.Expand description
Query parameters for listing projects.
Fields
limit: Option<u32>A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
after: Option<String>A cursor for use in pagination. after is an object ID that defines your place in the
list.
include_archived: Option<bool>If true returns all projects including those that have been archived. Archived projects
are not included by default.