pub struct ListProjectsQueryArgs { /* private fields */ }Available on crate feature
administration-types only.Expand description
Builder for ListProjectsQuery.
Implementations
Sourceimpl ListProjectsQueryArgs
impl ListProjectsQueryArgs
Sourcepub fn limit<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn limit<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
Sourcepub fn after<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn after<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A cursor for use in pagination. after is an object ID that defines your place in the
list.
Sourcepub fn include_archived<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn include_archived<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true returns all projects including those that have been archived. Archived projects
are not included by default.
Sourcepub fn build(&self) -> Result<ListProjectsQuery, OpenAIError>
pub fn build(&self) -> Result<ListProjectsQuery, OpenAIError>