pub struct ProjectGroupListResource {
pub object: String,
pub data: Vec<ProjectGroup>,
pub has_more: bool,
pub next: Option<String>,
}Available on crate feature
administration-types only.Expand description
Paginated list of groups that have access to a project.
Fields
object: StringThe object type, which is always list.
data: Vec<ProjectGroup>Project group memberships returned in the current page.
has_more: boolWhether additional project group memberships are available.
next: Option<String>Cursor to fetch the next page of results, or null when there are no more results.