pub struct ListFineTuningEventsQuery {
pub after: Option<String>,
pub limit: Option<u32>,
pub order: Option<ListFineTuningEventsOrder>,
}Available on crate feature
finetuning-types only.Expand description
Query parameters for listing fine-tuning events.
Fields
after: Option<String>Identifier for the last event from the previous pagination request.
limit: Option<u32>Number of events to retrieve.
order: Option<ListFineTuningEventsOrder>Sort order for events by timestamp. Use asc for ascending order or desc for descending
order. Defaults to asc.