pub struct ListFineTuningEventsQueryArgs { /* private fields */ }Available on crate feature
finetuning-types only.Expand description
Builder for ListFineTuningEventsQuery.
Implementations
Sourceimpl ListFineTuningEventsQueryArgs
impl ListFineTuningEventsQueryArgs
Sourcepub fn after<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn after<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Identifier for the last event from the previous pagination request.
Sourcepub fn limit<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
pub fn limit<VALUE: Into<u32>>(&mut self, value: VALUE) -> &mut Self
Number of events to retrieve.
Sourcepub fn order<VALUE: Into<ListFineTuningEventsOrder>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn order<VALUE: Into<ListFineTuningEventsOrder>>( &mut self, value: VALUE, ) -> &mut Self
Sort order for events by timestamp. Use asc for ascending order or desc for descending
order. Defaults to asc.
Sourcepub fn build(&self) -> Result<ListFineTuningEventsQuery, OpenAIError>
pub fn build(&self) -> Result<ListFineTuningEventsQuery, OpenAIError>