pub struct CreateVectorStoreFileBatchRequestArgs { /* private fields */ }vectorstore-types only.Expand description
Builder for CreateVectorStoreFileBatchRequest.
Implementations
Sourceimpl CreateVectorStoreFileBatchRequestArgs
impl CreateVectorStoreFileBatchRequestArgs
Sourcepub fn file_ids<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn file_ids<VALUE: Into<Vec<String>>>(&mut self, value: VALUE) -> &mut Self
A list of File IDs that the vector store
should use. Useful for tools like file_search that can access files. If attributes or
chunking_strategy are provided, they will be applied to all files in the batch. Mutually
exclusive with files.
Sourcepub fn files<VALUE: Into<Vec<CreateVectorStoreFileRequest>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn files<VALUE: Into<Vec<CreateVectorStoreFileRequest>>>( &mut self, value: VALUE, ) -> &mut Self
A list of objects that each include a file_id plus optional attributes or
chunking_strategy. Use this when you need to override metadata for specific files.
The global attributes or chunking_strategy will be ignored and must be specified
for each file. Mutually exclusive with file_ids.
pub fn chunking_strategy<VALUE: Into<ChunkingStrategyRequestParam>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn attributes<VALUE: Into<VectorStoreFileAttributes>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn attributes<VALUE: Into<VectorStoreFileAttributes>>( &mut self, value: VALUE, ) -> &mut Self
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
Sourcepub fn build(&self) -> Result<CreateVectorStoreFileBatchRequest, OpenAIError>
pub fn build(&self) -> Result<CreateVectorStoreFileBatchRequest, OpenAIError>
Builds a new CreateVectorStoreFileBatchRequest.
Errors
If a required field has not been initialized.