pub struct ListFilesInVectorStoreBatchQuery {
pub limit: Option<u32>,
pub order: Option<ListFilesInVectorStoreBatchOrder>,
pub after: Option<String>,
pub before: Option<String>,
pub filter: Option<ListFilesInVectorStoreBatchFilter>,
}Available on crate feature
vectorstore-types only.Expand description
Query parameters for listing files in vector store batch.
Fields
limit: Option<u32>A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
order: Option<ListFilesInVectorStoreBatchOrder>Sort order by the created_at timestamp of the objects. asc for ascending order and
desc for descending order.
after: Option<String>A cursor for use in pagination. after is an object ID that defines your place in the
list.
before: Option<String>A cursor for use in pagination. before is an object ID that defines your place in the
list.
filter: Option<ListFilesInVectorStoreBatchFilter>Filter by file status. One of in_progress, completed, failed, cancelled.